Learn R Programming

clippda (version 1.22.0)

liver_pheno: A dataframe of phenotypic information

Description

A dataframe containing the sample phenotypic information.

Usage

data(liver_pheno)

Arguments

Format

A data frame with 131 observations on the following 3 variables.
SampleTag
a character/numeric vector of sample ID.
tumor
a factor, with levels c and n, describing the class of the samples.
sex
a factor, with levels F and M, describing the gender of the persons from which the sample has been taken.

Ward DG, Cheng Y, N'Kontchou G, Thar TT, Barget N, Wei W, Billingham LJ, Martin A, Beaugrand M, Johnson PJ: Changes in the serum proteome associated with the development of hepatocellular carcinoma in hepatitis C-related cirrhosis. Br J Cancer. 2006, 94(2):287-92.

References

Ward DG, Cheng Y, N'Kontchou G, Thar TT, Barget N, Wei W, Billingham LJ, Martin A, Beaugrand M, Johnson PJ: Changes in the serum proteome associated with the development of hepatocellular carcinoma in hepatitis C-related cirrhosis. Br J Cancer. 2006, 94(2):287-92.

Examples

Run this code
data(liver_pheno)

Run the code above in your browser using DataLab