Learn R Programming

clippda (version 1.22.0)

pheno_urine: A dataframe of phenotypic information

Description

A dataframe containing the sample phenotypic information.

Usage

data(pheno_urine)

Arguments

Format

A data frame with 167 observations on the following 6 variables.
SpectrumTag
a character/numeric vector of sample ID.
Tumor
a factor, with levels c and n, describing the sample class
Age
a numeric vector of age.
Sex
a factor, with levels female and male, indicating gender.
stage
a factor, with levels early, late and normal, indicating tumor stage.
Protein_conc
a numeric vector of urine concentration.

Ward DG, Nyangoma S, Joy H, Hamilton E, Wei W, Tselepis C, Steven N, Wakelam MJ, Johnson PJ, Ismail T, Martin A: Proteomic profiling of urine for the detection of colon cancer. Proteome Sci. 2008, 16(6):19.

References

Ward DG, Nyangoma S, Joy H, Hamilton E, Wei W, Tselepis C, Steven N, Wakelam MJ, Johnson PJ, Ismail T, Martin A: Proteomic profiling of urine for the detection of colon cancer. Proteome Sci. 2008, 16(6):19.

Examples

Run this code
data(pheno_urine)

Run the code above in your browser using DataLab